@@ -3,10 +3,10 @@ import ast
 from abc import ABC, abstractmethod
 from collections import OrderedDict
 
-import numpy as np
-import geog
 import zipfile
 import fiona
+import logging
+import json
 
 from fiona.crs import from_epsg
 from geoalchemy2.shape import to_shape
@@ -46,6 +46,9 @@ FIONA_MAPPING = {
     "json": "str",
 }
 
+log = logging.getLogger()
+
+
 class FionaService(ABC):
     """
     Abstract class to provide functions to create geofiles with Fiona
@@ -125,8 +128,7 @@ class FionaService(ABC):
             try:
                 cls.build_feature(view, d, geo_colname, is_geojson)
             except UtilsSqlaError as e:
-                # TODO raise error or warning ??
-                pass
+                log.exception(f"Can not build feature for geo column {geo_colname}")
 
         cls.close_files()
 
@@ -142,11 +144,13 @@ class FionaService(ABC):
             geo_colname (string) : nom de la colonne contenant le geom
         """
         # Test if geom data exists
-        if not hasattr(data, geo_colname):
-            raise UtilsSqlaError("Cannot create a shapefile record whithout a Geometry")
+        if not hasattr(data, geo_colname) or getattr(data, geo_colname) is None:
+            raise UtilsSqlaError(
+                "Cannot create a shapefile record whithout a geometry column or with an None geometry"
+            )
         # Build geometry
         if is_geojson:
-            geom = ast.literal_eval(getattr(data, geo_colname))
+            geom = json.loads(getattr(data, geo_colname))
 
         else:
             geom = getattr(data, geo_colname)
@@ -266,13 +270,15 @@ class FionaShapeService(FionaService):
     Service to create shapefiles from sqlalchemy models
 
     How to use:
-    FionaShapeService.create_shapes_struct(**args)
+    FionaShapeService.create_fiona_struct(**args)
     FionaShapeService.create_features(**args)
-    FionaShapeService.save_and_zip_shapefiles()
+    FionaShapeService.save_files()
     """
 
     @classmethod
-    def create_fiona_struct(cls, db_cols, srid, dir_path, file_name, col_mapping=None):
+    def create_fiona_struct(
+        cls, db_cols, srid, dir_path, file_name, col_mapping=None, encoding="utf-8"
+    ):
         """
         Create three shapefiles (point, line, polygon) with the attributes give by db_cols
         Parameters:
@@ -281,6 +287,8 @@ class FionaShapeService(FionaService):
             dir_path (str): directory path
             file_name (str): file of the shapefiles
             col_mapping (dict): mapping between SQLA class attributes and 'beatifiul' columns name
+            encoding (str): define encoding of data to store in Shape. Default: utf-8.
+
 
         Returns:
             void
@@ -310,10 +318,20 @@ class FionaShapeService(FionaService):
         cls.polygon_feature = False
         cls.polyline_feature = False
         cls.point_shape = fiona.open(
-            cls.file_point, "w", "ESRI Shapefile", cls.point_schema, crs=cls.source_crs
+            cls.file_point,
+            "w",
+            "ESRI Shapefile",
+            cls.point_schema,
+            crs=cls.source_crs,
+            encoding=encoding,
         )
         cls.polygone_shape = fiona.open(
-            cls.file_poly, "w", "ESRI Shapefile", cls.polygon_schema, crs=cls.source_crs
+            cls.file_poly,
+            "w",
+            "ESRI Shapefile",
+            cls.polygon_schema,
+            crs=cls.source_crs,
+            encoding=encoding,
         )
         cls.polyline_shape = fiona.open(
             cls.file_line,
@@ -321,6 +339,7 @@ class FionaShapeService(FionaService):
             "ESRI Shapefile",
             cls.polyline_schema,
             crs=cls.source_crs,
+            encoding=encoding,
         )
 
     # TODO mark as deprecated
@@ -471,20 +490,6 @@ def export_geodata_as_file(
         pass
 
 
-def circle_from_point(point, radius, nb_point=20):
-    """
-    return a circle (shapely POLYGON) from a point
-    parameters:
-        - point: a shapely POINT
-        - radius: circle's diameter in meter
-        - nb_point: nb of point of the polygo,
-
-    """
-    angles = np.linspace(0, 360, nb_point)
-    polygon = geog.propagate(point, angles, radius)
-    return Polygon(polygon)
-
-
 def convert_to_2d(geojson):
     """
     Convert a geojson 3d in 2d
